<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Request a Quote Hyva Compatibility
 */

namespace Amasty\RequestQuoteHyva\ViewModel\Cart;

use Amasty\Base\Model\Serializer;
use Amasty\RequestQuote\Api\Data\QuoteInterface;
use Amasty\RequestQuoteHyva\Model\ConfigProvider;
use Magento\Framework\View\Element\Block\ArgumentInterface;

class Item implements ArgumentInterface
{
    /**
     * @var Serializer
     */
    private Serializer $serializer;

    /**
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    public function __construct(
        Serializer $serializer,
        ConfigProvider $configProvider
    ) {
        $this->serializer = $serializer;
        $this->configProvider = $configProvider;
    }

    public function retrieveCustomerNote(?string $additionalData): string
    {
        $customerNote = '';
        if ($additionalData === null) {
            return $customerNote;
        }

        $additionalData = $this->serializer->unserialize($additionalData);
        if (isset($additionalData[QuoteInterface::CUSTOMER_NOTE_KEY])) {
            $customerNote = $additionalData[QuoteInterface::CUSTOMER_NOTE_KEY];
        }

        return $customerNote;
    }

    public function isAllowCustomizePrice(): bool
    {
        return $this->configProvider->isAllowCustomizePrice();
    }
}
